<?php
/**
 * Plugin Name:        Safe Block Editor by WPMarmite
 * Description:        Simplifies your authoring experience by removing distracting options in the WordPress editor.
 * Version:            1.0
 * Author:             Modern Plugins
 * Author URI:         https://modernplugins.com/
 * Contributors:       modernplugins, vincentdubroeucq
 * License:            GPL v3 or later
 * License URI:        https://www.gnu.org/licenses/gpl-3.0.html
 * Text Domain:        safe-block-editor
 * Domain Path:        languages/
 * Requires at least:  5.0
 * Tested up to:       5.4.1
 */

/*
Safe Block Editor is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
any later version.
 
Safe Block Editor is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
 
You should have received a copy of the GNU General Public License
along with Safe Block Editor. If not, see https://www.gnu.org/licenses/gpl-3.0.html.
*/

defined( 'ABSPATH' ) || die();

define( 'SAFE_BLOCK_EDITOR_PATH', plugin_dir_path( __FILE__ ) );
define( 'SAFE_BLOCK_EDITOR_URL', plugin_dir_url( __FILE__ ) );


add_action( 'after_setup_theme', 'safe_block_editor_setup', 999 );
/**
 * Disable the custom color picker.
 */
function safe_block_editor_setup() {

    // Disable font sizes. Keep theme font sizes only
    // $theme_font_sizes   = get_theme_support( 'editor-font-sizes' );
    // $disable_font_sizes =  apply_filters( 'safe_block_editor_disable_font_sizes', empty( $theme_font_sizes ) );
	// if( $disable_font_sizes ) {
    //     add_theme_support( 'editor-font-sizes' );
    // }
    add_theme_support( 'editor-font-sizes' );
    add_theme_support( 'disable-custom-font-sizes' );

    // Disable colors. By default, keep theme's palette.
    // $theme_palette   = get_theme_support( 'editor-color-palette' );
    // $disable_palette = apply_filters( 'safe_block_editor_disable_color_palette', empty( $theme_palette ) );
	// if( $disable_palette ) {
    //     add_theme_support( 'editor-color-palette' );
    // }
    add_theme_support( 'editor-color-palette' );
    add_theme_support( 'disable-custom-colors' );
    
    // Disable gradients. By default keep theme's gradients
    // $theme_gradients   = get_theme_support( 'editor-gradient-presets' );
	// $disable_gradients = apply_filters( 'safe_block_editor_disable_gradient_presets', empty( $theme_gradients ) );
	// if( $disable_gradients ) {
    //     add_theme_support( 'editor-gradient-presets', array() );
    //     add_theme_support( '__experimental-editor-gradient-presets', array() );
    // }
    add_theme_support( 'editor-gradient-presets', array() );
    add_theme_support( '__experimental-editor-gradient-presets', array() );
    add_theme_support( 'disable-custom-gradients' );
    add_theme_support( '__experimental-disable-custom-gradients' );
    
    // Disable support for wide and full alignment
    if( get_theme_support( 'align-wide' ) ){
        remove_theme_support( 'align-wide' );
    }
}


/**
 * Returns an array of block editor settings to override
 */
function safe_block_editor_get_settings(){
    $settings = [
        'supports'        => safe_block_editor_get_supports(),
        'formats'         => safe_block_editor_get_richtext_formats(),
        'stylesBlackList' => safe_block_editor_get_styles_blacklist(),
        'blocksBlacklist' => safe_block_editor_get_blocks_blacklist(),
    ];
    return apply_filters( 'safe_block_editor_settings', $settings );
}


/**
 * Returns rich text formats to override
 * 
 * Passing false to a format will disable it.
 */
function safe_block_editor_get_richtext_formats(){
    $formats = array(
        'core/image' => false,
    );
    return apply_filters( 'safe_block_editor_richtext_formats', $formats );
}


/**
 * Returns blocks to remove
 */
function safe_block_editor_get_blocks_blacklist(){
    $blocks = array(
        'core/cover',
        'core/html',
        'core/verse',
        'core/pullquote',
        'core/group',
        'core/column',
        'core/columns',
        'core/media-text',
        'core/categories',
        'core/latest-comments',
        'core/latest-posts',
        'core/calendar',
        'core/rss',
        'core/search',
        'core/social-links',
        'core/social-link',
        'core/archives',
        'core/shortcode',
        'core/tag-cloud',
    );
    return apply_filters( 'safe_block_editor_blocks_blacklist', $blocks );
}


/**
 * Returns block styles to override
 * Passing an empty array will disable all styles. 
 */
function safe_block_editor_get_styles_blacklist(){
    $styles = array(
        'core/image'     => array( 'default', 'rounded' ),
        'core/quote'     => array( 'default', 'large' ),
        'core/pullquote' => array( 'default', 'solid-color' ),
        'core/button'    => array( 'fill', 'outline' ),
        'core/table'     => array( 'regular', 'stripes' ),
    );
    return apply_filters( 'safe_block_editor_styles_blackList', $styles );
}


/**
 * Returns the supports overrides
 */
function safe_block_editor_get_supports(){
    $supports = array(
        'anchor'          => false,
        // 'customClassName' => false,
        'html'            => false,
        'reusable'        => false,
    );
    return apply_filters( 'safe_block_editor_supports', $supports );
}


add_action( 'enqueue_block_editor_assets', 'safe_block_editor_block_editor_scripts', 100 );
/**
 * Registers block editor JS that de-registers blocks and styles. 
 */
function safe_block_editor_block_editor_scripts() {
    $version = get_plugin_data( __FILE__, false,false )['Version'];
    wp_enqueue_script( 'safe-block-editor-js', SAFE_BLOCK_EDITOR_URL . 'js/block-editor.js', array( 'wp-blocks', 'wp-hooks', 'wp-dom-ready', 'wp-edit-post' ), $version, true );
    wp_enqueue_style( 'safe-block-editor', SAFE_BLOCK_EDITOR_URL . 'css/block-editor.css', array(), $version );
    wp_localize_script( 'safe-block-editor-js', 'safeEditorSettings', safe_block_editor_get_settings() );
}


add_action( 'admin_notices', 'safe_block_editor_admin_notice' );
/**
 * Displays a warning concerning potential block validation error
 */
function safe_block_editor_admin_notice(){
    $dismissed = get_user_meta( get_current_user_id(), 'safe_editor_notice_dismissed' , true );
    if( ! $dismissed ){
        $dismiss_url = add_query_arg( array(
            'action'   => 'safe_block_editor_dismiss_notice',
            '_wpnonce' => wp_create_nonce( 'safe_block_editor_dismiss_notice' ),
        ), admin_url('admin-post.php') );
    ?>
        <div class="notice notice-warning is-dismissible">
            <p><?php _e( 'Thanks&nbsp;! You just activated Safe Block Editor&nbsp;! Some blocks, styles, and settings are no longer available in the WordPress editor.', 'safe-block-editor' ); ?></p>
            <p><?php _e( 'Nothing should be changed on the front end of the site, but you <strong>may</strong> get validation errors from the editor when updating posts. If that is the case, you should be able to safely recover your content using the <em>Resolve</em> or <em>Convert to HTML</em> recovery options.', 'safe-block-editor' ); ?></p>
            <p><a href="<?php echo esc_attr( esc_url( $dismiss_url ) ); ?>"><?php _e( 'Ok, I got it !', 'safe-block-editor' ); ?></a></p>
        </div>
    <?php
    }
}


add_action( 'admin_post_safe_block_editor_dismiss_notice', 'safe_block_editor_dismiss_notice' );
/**
 * Saves the user preference to not display the notice anymore.
 */
function safe_block_editor_dismiss_notice(){
    if ( ! isset( $_GET['_wpnonce'] ) || ! wp_verify_nonce( $_GET['_wpnonce'], 'safe_block_editor_dismiss_notice' ) ){
        return;
    }
    update_user_meta( get_current_user_id(), 'safe_editor_notice_dismissed', true );
    wp_safe_redirect( wp_get_referer() );
    exit;  
}
